@@ -5,6 +5,9 @@ use serde::Deserialize;
 pub struct RepositoryConfig {
     pub manifest: String,
     pub app: String,
+    pub catalog_schema: String,
+    pub catalogs: String,
+    pub reset: Option<bool>,
 }
 
 #[derive(Deserialize)]
